pub fn indent_string(string: &str) -> StringExpand description
Indent each line of string by a single space.
Equivalent to indent_string_with(string, 1, " ", false).
assert_eq!(indent_string("a\nb"), " a\n b");pub fn indent_string(string: &str) -> StringIndent each line of string by a single space.
Equivalent to indent_string_with(string, 1, " ", false).
assert_eq!(indent_string("a\nb"), " a\n b");